"""
Support for fMRI analysis in nitime:

This includes:

- ``io``: input and output of fMRI files to time-series objects

"""

import io
import hrf
import tests
